##  Step1: Install Tech Platforms
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2757d66e7a441014b912e08746d65c5b_LowRes.png)
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2756aafd7a4410148079d537346bd63b_LowRes.png)
